==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>创建平面图像...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>在三维空间中创建平面图像</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>三维空间中创建一个平面图像</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>打开...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>打开图像视图</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>图片视图的色彩模式未定义</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>图像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>选择方向</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>图像平面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY平面</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ平面</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ平面</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>反转方向</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>偏移:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>适应图像尺寸(&amp;F)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>拉伸图像以适应视图</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 缩放</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>按1:1比例显示图像</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>原始色(&amp;O)</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>以原始色显示图像</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>高亮色(&amp;B)</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>以高亮色显示图像</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>就绪...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>图像外部</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>图像浏览器</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>图像(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>选择一个图像文件打开</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>所有文件</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>打开图像时出错。</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>不能加载所选图像</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>打开图像错误</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>无法加载选择的图像</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>创建平面图像...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>在三维空间中创建平面图像</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>三维空间中创建一个平面图像</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>打开...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>打开图像视图</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>缩放...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>图像缩放</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>图片视图的色彩模式未定义</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>图像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>选择方向</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>图像平面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY平面</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ平面</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ平面</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>反转方向</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>偏移:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>适应图像尺寸(&amp;F)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>拉伸图像以适应视图</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 缩放</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>按1:1比例显示图像</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>原始色(&amp;O)</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>以原始色显示图像</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>高亮色(&amp;B)</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>以高亮色显示图像</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>就绪...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>图像外部</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>图像浏览器</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>图像(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>选择一个图像文件打开</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>图像</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>所有文件</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>打开图像时出错。</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>不能加载所选图像</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>打开图像错误</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>无法加载选择的图像</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
  </context>
</TS>
